arg-package: arg: Clean and Simple Argument Checking

arg-packageR Documentation

arg: Clean and Simple Argument Checking

Description

Checks function arguments, ideally for use in R packages. Uses a simple interface and produces clean, informative error messages using 'cli'.

Author(s)

Maintainer: Noah Greifer noah.greifer@gmail.com (ORCID)

See Also

Useful links:


arg documentation built on April 9, 2026, 5:09 p.m.