| arg_function | R Documentation |
Checks whether an argument is a function.
arg_function(x, .arg = rlang::caller_arg(x), .msg = NULL, .call)
x |
the argument to be checked |
.arg |
the name of the argument supplied to |
.msg |
an optional alternative message to display if an error is thrown instead of the default message. |
.call |
the execution environment of a currently running function, e.g. |
Returns NULL invisibly if an error is not thrown.
rlang::is_function(), arg_is()
f <- function(z) {
arg_function(z)
}
try(f(print)) # No error
try(f("print")) # Error: must be a function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.