| arg_supplied | R Documentation |
Checks whether an argument with no default value was supplied. An error will be thrown if rlang::is_missing(x) is TRUE, i.e., if an argument with no default is omitted from a function call.
arg_supplied(x, .arg = rlang::caller_arg(x), .msg = NULL, .call)
x |
the argument to be checked |
.arg |
the name of the argument supplied to |
.msg |
an optional alternative message to display if an error is thrown instead of the default message. |
.call |
the execution environment of a currently running function, e.g. |
Returns NULL invisibly if an error is not thrown.
arg_non_null(), arg_no_NA(), rlang::is_missing(), rlang::check_required()
f <- function(z) {
arg_supplied(z)
}
try(f(1)) ## No error: argument supplied
try(f()) ## Error!
# Will not throw for NULL or default arguments
try(f(NULL)) ## No error: argument supplied
f2 <- function(z = NULL) {
arg_supplied(z)
}
try(f2()) ## No error; default provided
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.